v1alpha1

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

This package has the automatically generated typed clients.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AppsV1alpha1Client

type AppsV1alpha1Client struct {
	// contains filtered or unexported fields
}

AppsV1alpha1Client is used to interact with features provided by the apps group.

func New

New creates a new AppsV1alpha1Client for the given RESTClient.

func NewForConfig

func NewForConfig(c *rest.Config) (*AppsV1alpha1Client, error)

NewForConfig creates a new AppsV1alpha1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).

func NewForConfigAndClient

func NewForConfigAndClient(c *rest.Config, h *http.Client) (*AppsV1alpha1Client, error)

NewForConfigAndClient creates a new AppsV1alpha1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.

func NewForConfigOrDie

func NewForConfigOrDie(c *rest.Config) *AppsV1alpha1Client

NewForConfigOrDie creates a new AppsV1alpha1Client for the given config and panics if there is an error in the config.

func (*AppsV1alpha1Client) NIMCaches

func (c *AppsV1alpha1Client) NIMCaches(namespace string) NIMCacheInterface

func (*AppsV1alpha1Client) NIMPipelines

func (c *AppsV1alpha1Client) NIMPipelines(namespace string) NIMPipelineInterface

func (*AppsV1alpha1Client) NIMServices

func (c *AppsV1alpha1Client) NIMServices(namespace string) NIMServiceInterface

func (*AppsV1alpha1Client) RESTClient

func (c *AppsV1alpha1Client) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

type AppsV1alpha1Interface

type AppsV1alpha1Interface interface {
	RESTClient() rest.Interface
	NIMCachesGetter
	NIMPipelinesGetter
	NIMServicesGetter
}

type NIMCacheExpansion

type NIMCacheExpansion interface{}

type NIMCacheInterface

type NIMCacheInterface interface {
	Create(ctx context.Context, nIMCache *v1alpha1.NIMCache, opts v1.CreateOptions) (*v1alpha1.NIMCache, error)
	Update(ctx context.Context, nIMCache *v1alpha1.NIMCache, opts v1.UpdateOptions) (*v1alpha1.NIMCache, error)
	// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
	UpdateStatus(ctx context.Context, nIMCache *v1alpha1.NIMCache, opts v1.UpdateOptions) (*v1alpha1.NIMCache, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.NIMCache, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.NIMCacheList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.NIMCache, err error)
	NIMCacheExpansion
}

NIMCacheInterface has methods to work with NIMCache resources.

type NIMCachesGetter

type NIMCachesGetter interface {
	NIMCaches(namespace string) NIMCacheInterface
}

NIMCachesGetter has a method to return a NIMCacheInterface. A group's client should implement this interface.

type NIMPipelineExpansion

type NIMPipelineExpansion interface{}

type NIMPipelineInterface

type NIMPipelineInterface interface {
	Create(ctx context.Context, nIMPipeline *v1alpha1.NIMPipeline, opts v1.CreateOptions) (*v1alpha1.NIMPipeline, error)
	Update(ctx context.Context, nIMPipeline *v1alpha1.NIMPipeline, opts v1.UpdateOptions) (*v1alpha1.NIMPipeline, error)
	// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
	UpdateStatus(ctx context.Context, nIMPipeline *v1alpha1.NIMPipeline, opts v1.UpdateOptions) (*v1alpha1.NIMPipeline, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.NIMPipeline, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.NIMPipelineList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.NIMPipeline, err error)
	NIMPipelineExpansion
}

NIMPipelineInterface has methods to work with NIMPipeline resources.

type NIMPipelinesGetter

type NIMPipelinesGetter interface {
	NIMPipelines(namespace string) NIMPipelineInterface
}

NIMPipelinesGetter has a method to return a NIMPipelineInterface. A group's client should implement this interface.

type NIMServiceExpansion

type NIMServiceExpansion interface{}

type NIMServiceInterface

type NIMServiceInterface interface {
	Create(ctx context.Context, nIMService *v1alpha1.NIMService, opts v1.CreateOptions) (*v1alpha1.NIMService, error)
	Update(ctx context.Context, nIMService *v1alpha1.NIMService, opts v1.UpdateOptions) (*v1alpha1.NIMService, error)
	// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
	UpdateStatus(ctx context.Context, nIMService *v1alpha1.NIMService, opts v1.UpdateOptions) (*v1alpha1.NIMService, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.NIMService, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.NIMServiceList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.NIMService, err error)
	NIMServiceExpansion
}

NIMServiceInterface has methods to work with NIMService resources.

type NIMServicesGetter

type NIMServicesGetter interface {
	NIMServices(namespace string) NIMServiceInterface
}

NIMServicesGetter has a method to return a NIMServiceInterface. A group's client should implement this interface.

Directories

Path Synopsis
Package fake has the automatically generated clients.
Package fake has the automatically generated clients.

Jump to